==> kmyfirewall-trinity_3.5.13.2.orig.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/ruleoptionplugins/tos_target_option/kmfruletargetoptionedittos.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITTOS_H
#define KMFRULETARGETOPTIONEDITTOS_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>
class KInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditorTos;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditTos : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditTos(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditTos();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorTos *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditTosFactory : public KLibFactory {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditTosFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditTosFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif

==> kmyfirewall-trinity-14.0.10.tar.xz: kmyfirewall-trinity-14.0.10/kmyfirewall/ruleoptionplugins/tos_target_option/kmfruletargetoptionedittos.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITTOS_H
#define KMFRULETARGETOPTIONEDITTOS_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <tdeparts/part.h>
#include <tdeparts/plugin.h>
#include <tdeparts/factory.h>
#include <kxmlgui.h>
class TDEInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditorTos;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditTos : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditTos(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditTos();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorTos *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditTosFactory : public KLibFactory {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditTosFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditTosFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static TDEInstance* instance(); */

/*private:
	static TDEInstance* s_instance;*/
};
}








#endif
